@@ -21,7 +21,7 @@ extract_probabilities_of <- function(data, probability_cols, of_col = "Target",
     # Binomial
 
     if (is.null(cat_levels)){
-      cat_levels <- levels_as_characters(data[[of_col]], drop_unused = TRUE)
+      cat_levels <- levels_as_characters(data[[of_col]], drop_unused = TRUE, sort_levels=TRUE)
     }
 
     if (length(cat_levels) != 2) {
@@ -29,7 +29,7 @@ extract_probabilities_of <- function(data, probability_cols, of_col = "Target",
     }
 
     if (is.numeric(positive))
-      positive <- cat_levels[positive]
+      positive <- cat_levels[[positive]]
 
     # Probability of 'of' column
     prob_of <-
