@@ -355,7 +355,9 @@ update_sum_tile_settings <- function(settings, defaults, initial_vals = NULL) {
       palette = "Greens",
       label = "\u2211",
       tile_fill = NULL,
-      font_color = NULL,
+      font_counts_color = NULL,
+      font_normalized_color = NULL,
+      dynamic_font_colors = dynamic_font_color_settings(),
       tile_border_color = NA,
       tile_border_size = 0.1,
       tile_border_linetype = "solid",
